/***************************************************************************
                          cursor3d.hpp  -  description
                             -------------------
    begin                : Mon Jul 3 2006
    copyright            : (C) 2006-2007 by Krippel Harald
    email                : harald@the-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/**3D-Cursor for QCake
  *@author Krippel Harald
  */

#ifndef CURSOR3D_H
#define CURSOR3D_H

#include <QtGui>
#include <plib/ssg.h>


//class cursor3d : public QCursor 
class cursor3d : public  QObject
{

 Q_OBJECT

public: 
   cursor3d(QObject *parent=0);
   ~cursor3d();
   void TurnOn();
   void TurnOff();
   void getPosition ( sgCoord  *cursorpos );
   int  Valid();
 
    sgVec3 poi;
    int x;
    int y;
    int on;

public slots:
   void   update(float dt);

protected:
    int valid;
};

#endif
